var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'whats_new.xml',
'whats_new_05.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'directory.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'wish_list.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'numeric_ad.xml',
'addon.xml',
'license.xml'
];
var list_down1 = [
'whats_new_17.xml',
'whats_new_16.xml',
'whats_new_15.xml',
'whats_new_14.xml',
'whats_new_13.xml',
'whats_new_12.xml',
'whats_new_11.xml',
'whats_new_10.xml',
'whats_new_09.xml',
'whats_new_08.xml',
'whats_new_07.xml',
'whats_new_06.xml',
'whats_new_05.xml',
'whats_new_04.xml',
'whats_new_03.xml'
];
var list_current0 = [
'whats_new_05.xml#12-24',
'whats_new_05.xml#12-23',
'whats_new_05.xml#12-22',
'whats_new_05.xml#12-20',
'whats_new_05.xml#12-19',
'whats_new_05.xml#12-16',
'whats_new_05.xml#12-15',
'whats_new_05.xml#12-14',
'whats_new_05.xml#12-11',
'whats_new_05.xml#12-08',
'whats_new_05.xml#12-07',
'whats_new_05.xml#12-06',
'whats_new_05.xml#12-05',
'whats_new_05.xml#12-03',
'whats_new_05.xml#12-02',
'whats_new_05.xml#12-01',
'whats_new_05.xml#11-23',
'whats_new_05.xml#11-22',
'whats_new_05.xml#11-20',
'whats_new_05.xml#11-19',
'whats_new_05.xml#11-15',
'whats_new_05.xml#11-12',
'whats_new_05.xml#11-09',
'whats_new_05.xml#11-07',
'whats_new_05.xml#11-06',
'whats_new_05.xml#11-01',
'whats_new_05.xml#10-20',
'whats_new_05.xml#10-18',
'whats_new_05.xml#10-14',
'whats_new_05.xml#10-12',
'whats_new_05.xml#10-06',
'whats_new_05.xml#09-29',
'whats_new_05.xml#09-27',
'whats_new_05.xml#09-24',
'whats_new_05.xml#09-20',
'whats_new_05.xml#09-14',
'whats_new_05.xml#09-09',
'whats_new_05.xml#09-07',
'whats_new_05.xml#08-30',
'whats_new_05.xml#08-24',
'whats_new_05.xml#08-20',
'whats_new_05.xml#08-19',
'whats_new_05.xml#08-15',
'whats_new_05.xml#08-14',
'whats_new_05.xml#08-13',
'whats_new_05.xml#08-07',
'whats_new_05.xml#07-21',
'whats_new_05.xml#07-19',
'whats_new_05.xml#07-15',
'whats_new_05.xml#07-11',
'whats_new_05.xml#07-08',
'whats_new_05.xml#07-05',
'whats_new_05.xml#07-04',
'whats_new_05.xml#07-03',
'whats_new_05.xml#07-02',
'whats_new_05.xml#07-01',
'whats_new_05.xml#06-25',
'whats_new_05.xml#06-24',
'whats_new_05.xml#06-18',
'whats_new_05.xml#06-14',
'whats_new_05.xml#06-13',
'whats_new_05.xml#06-06',
'whats_new_05.xml#05-19',
'whats_new_05.xml#05-18',
'whats_new_05.xml#05-16',
'whats_new_05.xml#05-12',
'whats_new_05.xml#05-06',
'whats_new_05.xml#05-01',
'whats_new_05.xml#04-21',
'whats_new_05.xml#04-20',
'whats_new_05.xml#04-19',
'whats_new_05.xml#03-26',
'whats_new_05.xml#03-23',
'whats_new_05.xml#03-22',
'whats_new_05.xml#03-09',
'whats_new_05.xml#03-04',
'whats_new_05.xml#03-01',
'whats_new_05.xml#02-24',
'whats_new_05.xml#01-08'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
